@@ -11,9 +11,9 @@
 #'                      csv = FALSE,
 #'                      xlsx = FALSE,
 #'                      lang = "both",
-#'                      cache = TRUE,
-#'                      update_cache=FALSE,
-#'                      compress_file = TRUE,
+#'                      cache = FALSE,
+#'                      update_cache = FALSE,
+#'                      compress_file = FALSE,
 #'                      cache_dir = "cache_dir")
 #' @param id_dataset Data set id.
 #' @param start_period Time value for the start (NULL by default).
@@ -21,11 +21,11 @@
 #' @param recent FALSE by default, if TRUE, the function retrieves data from last 10 years.
 #' @param csv FALSE by default, if TRUE, the function saves the data set to directory as .csv.
 #' @param xlsx FALSE by default, if TRUE, the function saves the data set to directory as .xlsx.
-#' @param lang Language parameter for labels ("ita" for Italian, "eng" for English).
-#' @param cache TRUE by default. If FALSE, the function retrieve the data set without caching.
+#' @param lang Language parameter for labels ("ita" for Italian, "eng" for English). By default both languages are returned. 
+#' @param cache FALSE by default. If TRUE, downloaded data are cached in the directory specified by `cache_dir`.
 #' @param update_cache FALSE by default. If TRUE, the cache is updated.
-#' @param compress_file TRUE by default. It compresses the RDS file in caching.
-#' @param cache_dir By default it saves the cache directory into the current working directory.
+#' @param compress_file FALSE by default. It compresses the RDS file when caching. Only used when `cache = TRUE`.
+#' @param cache_dir By default it saves the cache directory into the current working directory when `cache = TRUE`. The directory is created if it does not exist.
 #'
 #' @return It returns the data set as data.frame. It can be saved to environment or as .csv/.xlsx.
 #' @importFrom rsdmx readSDMX
@@ -37,8 +37,8 @@
 #' Downloading may take some time. Future versions will speed up the process.
 #'
 #' @examples \dontrun{get_i_stat("12_60", 
-#'                               start_period=2015, 
-#'                               end_period=2018, 
+#'                               start_period = 2015, 
+#'                               end_period = 2018, 
 #'                               lang = "eng", 
 #'                               cache = FALSE)}
 get_i_stat <- function(id_dataset,
@@ -48,9 +48,9 @@ get_i_stat <- function(id_dataset,
                        csv = FALSE,
                        xlsx = FALSE,
                        lang = "both",
-                       cache = TRUE,
-                       update_cache=FALSE,
-                       compress_file = TRUE,
+                       cache = FALSE,
+                       update_cache = FALSE,
+                       compress_file = FALSE,
                        cache_dir = "cache_dir") {
 
   if (cache && !dir.exists(cache_dir)) {
