@@ -2,7 +2,7 @@
 #'
 #' @usage list_istatdata(lang = "ita")
 #'
-#' @param lang language parameter for labels ("ita" for Italian, "eng" for English)
+#' @param lang language parameter for labels: "ita" for Italian (default), "eng" for English.
 #'
 #' @return It returns the complete list of available data sets from IstatData with their ids and names.
 #' @export
@@ -37,22 +37,22 @@ list_istatdata <- function(lang = "ita") {
     
   # removal of unavailable datasets
   istat.fl <- istat.fl %>%
-     filter(!id %in% c("152"
-    #                   "111_263_DF_DCSC_FIDIMPRMAN_11"
+     filter(!.data$id %in% c("152"
+    #                   ,"111_263_DF_DCSC_FIDIMPRMAN_11"
     #                   ,"111_263_DF_DCSC_FIDIMPRMAN_12"
     #                   ,"111_263_DF_DCSC_FIDIMPRMAN_13"
     #                   ,"111_263_DF_DCSC_FIDIMPRMAN_14"
     #                   ,"111_263_DF_DCSC_FIDIMPRMAN_15"
     #                   ,"111_263_DF_DCSC_FIDIMPRMAN_16"
     #                   ,"111_263_DF_DCSC_FIDIMPRMAN_9"
-    #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_4" #perchè giallo
-    #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_5" #perchè bianco
-    #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_6" #perchè bianco
+    #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_4" 
+    #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_5" 
+    #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_6" 
     #                   ,"117_262_DF_DCSC_FIDIMPRSERV_5"
     #                   ,"117_262_DF_DCSC_FIDIMPRSERV_6"
     #                   ,"117_262_DF_DCSC_FIDIMPRSERV_7"
     #                   ,"117_266_DF_DCSC_FIDCOMM_3"
-    #                   ,"117_266_DF_DCSC_FIDCOMM_4" #perchè giallo
+    #                   ,"117_266_DF_DCSC_FIDCOMM_4" 
     #                   ,"14_121_DF_DCCV_TRASPUB_1"
     #                   ,"14_166_DF_DCCV_INTBONRUM_1"
     #                   ,"14_167_DF_DCCV_MONINQACS_1"
