@@ -3,10 +3,10 @@
 #' Search I.Stat data sets by keywords. To download data sets, use "get_i_stat" function and insert data set ids.
 #'
 #' @usage search_i_stat(keywords,
-#'               lang = "ita")
+#'                      lang = "ita")
 #'
-#' @param keywords keyword(s) to search data sets
-#' @param lang language parameter for labels ("ita" for Italian, "eng" for English)
+#' @param keywords keyword(s) to search data sets.
+#' @param lang language parameter for labels: "ita" for Italian (default), "eng" for English.
 #'
 #' @return It returns a list of data sets containing the keyword(s) with their ids and names.
 #' @importFrom rsdmx readSDMX
@@ -14,8 +14,8 @@
 #' @note
 #'Searching may take some time. Future versions will speed up the process.
 #'
-#' @examples \donttest{search_i_stat(c( "incidenti", "stradali"))}
-#'\donttest{search_i_stat("population", lang="eng")}
+#' @examples \donttest{search_i_stat(c("incidenti", "stradali"))}
+#'\donttest{search_i_stat("population", lang = "eng")}
 search_i_stat <- function(keywords, lang = "ita") {
   if (!curl::has_internet()) {
     message(
@@ -50,7 +50,7 @@ search_i_stat <- function(keywords, lang = "ita") {
   } else if (lang == "eng") {
     name_column <- "Name.en"
   } else {
-    stop("Wrong language parameter. Use 'ita' for Italian and 'eng' for English.")
+    stop("Wrong language parameter. Use 'ita' for Italian or 'eng' for English.")
   }
 
   search_keyword <- function(keyword) {
