@@ -3,10 +3,10 @@
 #' Search IstatData data sets by keywords. To download data sets use "get_istatdata" function and insert data set ids.
 #'
 #' @usage search_istatdata(keywords,
-#'                  lang = "ita")
+#'                         lang = "ita")
 #'
-#' @param keywords keyword(s) to search data sets
-#' @param lang language parameter for labels ("ita" for Italian, "eng" for English)
+#' @param keywords keyword(s) to search data sets.
+#' @param lang language parameter for labels: "ita" for Italian (default), "eng" for English.
 #'
 #' @return It returns a list of data sets containing the keyword(s) with their ids and names.
 #' @importFrom rsdmx readSDMX
@@ -14,8 +14,8 @@
 #' @note
 #' Searching may take some time. Future versions will speed up the process.
 #'
-#' @examples \donttest{search_istatdata(c( "incidenti", "stradali"))}
-#'\donttest{search_istatdata("population", lang="eng")}
+#' @examples \donttest{search_istatdata(c("incidenti", "stradali"))}
+#'\donttest{search_istatdata("population", lang = "eng")}
 search_istatdata <- function(keywords, lang = "ita") {
   
   if (!curl::has_internet()) {
@@ -44,22 +44,22 @@ search_istatdata <- function(keywords, lang = "ita") {
   istat.fl <- as.data.frame(istat.fl)
 
   istat.fl <- istat.fl %>%
-    filter(!id %in% c("152"
-                      #                    "111_263_DF_DCSC_FIDIMPRMAN_11"
+    filter(!.data$id %in% c("152"
+                      #                   ,"111_263_DF_DCSC_FIDIMPRMAN_11"
                       #                   ,"111_263_DF_DCSC_FIDIMPRMAN_12"
                       #                   ,"111_263_DF_DCSC_FIDIMPRMAN_13"
                       #                   ,"111_263_DF_DCSC_FIDIMPRMAN_14"
                       #                   ,"111_263_DF_DCSC_FIDIMPRMAN_15"
                       #                   ,"111_263_DF_DCSC_FIDIMPRMAN_16"
                       #                   ,"111_263_DF_DCSC_FIDIMPRMAN_9"
-                      #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_4" #perchè giallo
-                      #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_5" #perchè bianco
-                      #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_6" #perchè bianco
+                      #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_4" 
+                      #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_5"
+                      #                   ,"111_40_DF_DCSC_FIDIMPRCOSTR_6"
                       #                   ,"117_262_DF_DCSC_FIDIMPRSERV_5"
                       #                   ,"117_262_DF_DCSC_FIDIMPRSERV_6"
                       #                   ,"117_262_DF_DCSC_FIDIMPRSERV_7"
                       #                   ,"117_266_DF_DCSC_FIDCOMM_3"
-                      #                   ,"117_266_DF_DCSC_FIDCOMM_4" #perchè giallo
+                      #                   ,"117_266_DF_DCSC_FIDCOMM_4"
                       #                   ,"14_121_DF_DCCV_TRASPUB_1"
                       #                   ,"14_166_DF_DCCV_INTBONRUM_1"
                       #                   ,"14_167_DF_DCCV_MONINQACS_1"
@@ -230,14 +230,14 @@ search_istatdata <- function(keywords, lang = "ita") {
                       ,"DF_BULK_UNIVERSITY_DEGREE"
                       ,"DF_DCAT_CENSAGRIC2020_AGE_MAR"
                       ,"DF_DIFF_REPORT"
-                      , "DF_TEST_DCIS_ABORTISPONTL"))
+                      ,"DF_TEST_DCIS_ABORTISPONTL"))
 
   if (lang == "ita") {
     name_column <- "Name.it"
   } else if (lang == "eng") {
     name_column <- "Name.en"
   } else {
-    stop("Wrong language parameter. Use 'ita' for Italian and 'eng' for English.")
+    stop("Wrong language parameter. Use 'ita' for Italian or 'eng' for English.")
   }
 
   search_keyword <- function(keyword) {
