@@ -36,7 +36,7 @@
 #' @export
 #'
 #' @note
-#' Calling a ShinyApp equals to calling a R function. For this reason, once called shinyIstat(), R will be busy processing it until the app will be closed. As a consequence, all other R functionalities can be processed only when the app is closed.
+#' Calling a ShinyApp equals to calling a R function. For this reason, once called shinyIstat(), R will be busy processing it until the app is closed. As a consequence, all other R console commands can be processed only when the app is closed.
 #'
 #' @examples
 #' if(interactive()) {
@@ -99,15 +99,19 @@ shinyIstat <- function(){
                         ),
                         p("Use the menu on the left to navigate through the app.
                       Inside each panel you will find further help."),
-                        h4("UPDATE 1.1.0 - December 2025"),
-                        p(HTML("The functions <i>list_istatdata</i> and <i>search_istatdata</i> and have been updated but they work in the 
+                        
+                        h4("UPDATES"),
+                        tags$ul(
+                          tags$li(HTML("<b>Version <i>1.1.1</i> - December 2025</b>: The functions <i>list_istatdata</i> and <i>search_istatdata</i> and have been updated but they work in the 
                                same way as the previous version, while <i>get_istatdata</i> has been updated and it now requires less 
                                parameters: there is no need to specify the <b>version</b> and the <b>agencyId</b> anymore and it 
                                works just like <i>get_i_stat</i> function. Moreover, the website dati.istat.it has been dismissed, but 
                                it is still possible to retrieve data from this provider. We do not know if and when it will not be 
                                possible anymore thus we recommend to rely on the new functions (<i>_istatdata</i>). Lastly, all of the 
                                functions accessing ISTAT web services have been updated to fail gracefully when Internet resources 
-                               are unavailable or have changed, with informative messages.")),
+                               are unavailable or have changed, with informative messages. ")),
+                          tags$li(HTML("<b>Version <i>1.1.2</i> - January 2026</b>: Fixed compatibility with an upcoming <i>dplyr</i> package release."))
+                        ),
                         p(HTML("<b>NOTES</b>:")),
                         tags$ul(
                           tags$li("For a better experience, use the app in full-screen."),
@@ -135,7 +139,7 @@ shinyIstat <- function(){
                                             <hr>
                                             <p><b>Complete list:</b> simply select the language and click on '<b>Load Data</b>' to obtain the complete list of available datasets from <i>I.Stat</i>.</p>
                                             <p><b>Search datasets:</b> insert keywords separated by commas (,) and select language. You will obtain a list of datasets containing all keywords inserted and the list of the datasets that contain the single keywords. Each dataset has its <b>id</b> and <b>name</b> of the dataset. You will need the id to download the dataset.</p>
-                                            <p><b>NOTE</b>: if you searched the dataset through <i>I.Stat</i> and you want to download it, you have to click on <b>Get dataset -->I.Stat</b></p>" )),
+                                            <p><b>NOTE</b>: if you searched the dataset through <i>I.Stat</i> and you want to download it, you have to click on <b><i>Get dataset -->I.Stat</i></b></p>" )),
                                                       fade = TRUE
                                               ),
                                             actionButton("load_data_i", "Load", styleclass = "primary", icon = NULL),
@@ -162,7 +166,7 @@ shinyIstat <- function(){
                                             <hr>
                                             <p><b>Complete list:</b> simply select the language and click on '<b>Load</b>' to obtain the complete list of available datasets from <i>I.Stat</i>.</p>
                                             <p><b>Search datasets:</b> insert keywords separated by commas (,) and select language. You will obtain a list of datasets containing all keywords inserted and the list of the datasets that contain the single keywords. Each dataset has its <b>id</b> and <b>name</b> of the dataset. You will need the id to download the dataset.</p>
-                                            <p><b>NOTE</b>: if you searched the dataset through <i>I.Stat</i> and you want to download it, you have to click on <b>Get dataset -->I.Stat</b></p>" )),
+                                            <p><b>NOTE</b>: if you searched the dataset through <i>I.Stat</i> and you want to download it, you have to click on <b><i>Get dataset -->I.Stat</i></b></p>" )),
                                                       fade = TRUE
                                               ),
                                             selectInput("langi", "Language:",
@@ -204,7 +208,7 @@ shinyIstat <- function(){
                                                         "<h1 style='color:navy;'>Search for available datasets: <i>IstatData</i></h1>
                                             <hr>
                                             <p><b>Complete list:</b> simply select the language and click on '<i>Load </i>' to obtain the complete list of available datasets from <i>IstatData</i>.</p>
-                                            <p><b>Search datasets:</b> insert keywords separated by commas (,) and select language. You will obtain a list of datasets containing all keywords inserted and the list of the datasets that contain the single keywords. Each dataset has its <b>agencyId</b>, <b>id</b>, <b>version</b> and <b>name</b> of the dataset. You will need these information to download the dataset.</p>
+                                            <p><b>Search datasets:</b> insert keywords separated by commas (,) and select language. You will obtain a list of datasets containing all keywords inserted and the list of the datasets that contain the single keywords. Each dataset has its <b>id</b> and <b>name</b> of the dataset. You will need the id to download the dataset.</p>
                                             <p><b>*NOTE</b>: if you searched the dataset through <i>IstatData</i> and you want to download it, you have to click on <b><i>Get dataset -->IstatData</i></b></p>" )),
                                                       fade = TRUE
                                               ),
@@ -228,7 +232,7 @@ shinyIstat <- function(){
                                                          "<h1 style='color:navy;'>Search for available datasets: <i>IstatData</i></h1>
                                               <hr>
                                               <p><b>Complete list:</b> simply select the language and click on '<i>Load Data</i>' to obtain the complete list of available datasets from <i>IstatData</i>.</p>
-                                              <p><b>Search datasets:</b> insert keywords separated by commas (,) and select language. You will obtain a list of datasets containing all keywords inserted and the list of the datasets that contain the single keywords. Each dataset has its <b>agencyId</b>, <b>id</b>, <b>version</b> and <b>name</b> of the dataset. You will need these information to download the dataset.</p>
+                                              <p><b>Search datasets:</b> insert keywords separated by commas (,) and select language. You will obtain a list of datasets containing all keywords inserted and the list of the datasets that contain the single keywords. Each dataset has its <b>id</b> and <b>name</b> of the dataset. You will need the id to download the dataset.</p>
                                               <p><b>*NOTE</b>: if you searched the dataset through <i>IstatData</i> and you want to download it, you have to click on <b><i>Get dataset -->IstatData</i></b></p>" )),
                                                        fade = TRUE
                                                ),
@@ -269,7 +273,7 @@ shinyIstat <- function(){
                                                   type = "inline",
                                                   content = c(paste(
                                                     "<h1 style=\"color:navy;\"> Download datasets: <i>I.Stat</i> </h1>
-                                             <p><b>Id dataset</b>: insert the id of the wanted dataset. You can find the id through <i> Available datasets -->I.stat -->Complete list</i> or <i>Search datasets</i> to find a dataset by keyword(s).</p>
+                                             <p><b>Id dataset</b>: insert the id of the wanted dataset. You can find the id through <i> Available datasets -->I.Stat -->Complete list</i> or <i>Search datasets</i> to find a dataset by keyword(s).</p>
                                              <p><b>Language</b>: select the language of the labels. You can choose between <i>Italian</i>, <i>English</i> or <i>both</i>.</p>
                                              <p>With <b><i>Time period</i></b> you can choose between:</p>
                                              <ul>
@@ -322,7 +326,7 @@ shinyIstat <- function(){
                                                   size = "m",
                                                   type = "inline",
                                                   content = c(paste(
-                                                    "<h1 style=\"color:navy;\"> Download datasets: <i>I.Stat</i> </h1>
+                                                    "<h1 style=\"color:navy;\"> Download datasets: <i>IstatData</i> </h1>
                                              <p><b>Id dataset</b>: insert the id of the wanted dataset. You can find the id through <i> Available datasets -->IstatData -->Complete list</i> or <i>Search datasets</i> to find a dataset by keyword(s).</p>
                                              <p><b>Language</b>: select the language of the labels. You can choose between <i>Italian</i>, <i>English</i> or <i>both</i>.</p>
                                              <p>With <b><i>Time period</i></b> you can choose between:</p>
@@ -707,8 +711,8 @@ shinyIstat <- function(){
 
         # removal of unavailable datasets
         istat.flve <- istat.flve %>%
-          filter(!id %in% c("152"
-                            #                    "111_263_DF_DCSC_FIDIMPRMAN_11"
+          filter(!.data$id %in% c("152"
+                            #                   ,"111_263_DF_DCSC_FIDIMPRMAN_11"
                             #                   ,"111_263_DF_DCSC_FIDIMPRMAN_12"
                             #                   ,"111_263_DF_DCSC_FIDIMPRMAN_13"
                             #                   ,"111_263_DF_DCSC_FIDIMPRMAN_14"
@@ -893,7 +897,7 @@ shinyIstat <- function(){
                             ,"DF_BULK_UNIVERSITY_DEGREE"
                             ,"DF_DCAT_CENSAGRIC2020_AGE_MAR"
                             ,"DF_DIFF_REPORT"
-                            , "DF_TEST_DCIS_ABORTISPONTL"))
+                            ,"DF_TEST_DCIS_ABORTISPONTL"))
 
         ID <- istat.flve$id
 
@@ -1026,8 +1030,8 @@ shinyIstat <- function(){
         istat.flve <- as.data.frame(istat.flve)
 
         istat.flve <- istat.flve %>%
-          filter(!id %in% c("152"
-                            #                    "111_263_DF_DCSC_FIDIMPRMAN_11"
+          filter(!.data$id %in% c("152"
+                            #                   ,"111_263_DF_DCSC_FIDIMPRMAN_11"
                             #                   ,"111_263_DF_DCSC_FIDIMPRMAN_12"
                             #                   ,"111_263_DF_DCSC_FIDIMPRMAN_13"
                             #                   ,"111_263_DF_DCSC_FIDIMPRMAN_14"
